var canvas = document.getElementById("canvas");
var context = canvas.getContext("2d");
var rad = 3.14/180;
var radius = 62;
var originX = 64;
var originY = 64;

var image = new Image(128, 128);
image.src = "Image/moon.png";

function drawMoon()
{
	var borderX, R, x, y, th, sign, clockwise, prop, age;
	var hasRisen = true;
	
    context.clearRect(0, 0, 128, 128);
    context.drawImage(image, 0, 0);

	if (MoonAgePlugin) {
		var now = new Date();
		var year, month, day, hour, min, sec;
		year = now.getFullYear();
		month = now.getMonth() + 1;
		day = now.getDate();
		hour = now.getHours();
		min = now.getMinutes();
		sec = now.getSeconds();
	
//		MoonAgePlugin.setup();
//		MoonAgePlugin.setupWithYear_month_day_hour_minute_second_(2005,11,02,13,26,0);
		MoonAgePlugin.setupWithYear_month_day_hour_minute_second_(year, month, day, hour, min, sec);
		prop = MoonAgePlugin.getIllumiProp();
		sign = MoonAgePlugin.getPhaseSign();
		age = MoonAgePlugin.getMoonAge();
		
		var lng = document.getElementById("lng").value;
		var lat = document.getElementById("lat").value;

		var format = "%Y/%m/%d %H:%M:%S";//"%b %d, %Y %H:%M:%S";
		var riseStr = MoonAgePlugin.getMoonRiseTimeWithLongitude_latitude_format_(lng, lat, format);
		var setStr = MoonAgePlugin.getMoonSetTimeWithLongitude_latitude_format_(lng, lat, format);
		
		// 基準時刻からの秒数
		var rise_msec = Date.parse(riseStr);
		var now_msec = Date.parse(now.toString());
		var set_msec = Date.parse(setStr);
		
		// 出,今,入
		// 入,今,出
		// 出,入,今
		// 入,出,今
		// 今,入,出
		// 今,出,入
		var msecs = new Array(rise_msec, now_msec, set_msec);
		// 昇順ソート
		msecs.sort();
		
		var retry = "none";		
		if (msecs[0] == now_msec) {
			hour -= 14;
			if (msecs[1] == rise_msec) {
				// 今,出,入 -> 入,今,出
				retry = "set";
				hasRisen = false;
			} else {
				// 今,入,出 -> 出,今,入
				retry = "rise";
				hasRisen = true;
			}
		} else if (msecs[1] == now_msec) {
			if (msecs[0] == rise_msec) {
				// 出,今,入
				hasRisen = true;
			} else {
				// 入,今,出
				hasRisen = false;
			}		
		} else if (msecs[2] == now_msec) {
			hour += 14;
			if (msecs[1] == rise_msec) {
				// 入,出,今 -> 出,今,入
				retry = "set";
				hasRisen = true;
			} else {
				// 出,入,今 -> 入,今,出
				retry = "rise";
				hasRisen = false;
			}
		}
		if (retry != "none") {
			// 「今」を真ん中に持ってくるように再計算
			MoonAgePlugin.setupWithYear_month_day_hour_minute_second_(year, month, day, hour, min, sec);
			if (retry == "rise") {
				riseStr = MoonAgePlugin.getMoonRiseTimeWithLongitude_latitude_format_(lng, lat, format);
			} else {
				setStr = MoonAgePlugin.getMoonSetTimeWithLongitude_latitude_format_(lng, lat, format);
			}
		}
		// 年 を取り除く
		riseStr = riseStr.substring(5, riseStr.length);
		setStr = setStr.substring(5, setStr.length);
		
		// 経緯度に方角を追加		
		var lngDir = (lng > 0) ? "E" : "W";
		var latDir = (lat > 0) ? "N" : "S";
		
		document.getElementById("age").innerText = age;
		document.getElementById("location").innerText = Math.abs(lng) + lngDir + ", " + Math.abs(lat) + latDir;
		document.getElementById("rise").innerText = riseStr;
		document.getElementById("set").innerText = setStr;
	} else {
		return; 
	}
	
	if (!hasRisen) {
		// 上ってない
		context.setFillColor(0, 0, 0, 0.5);
		context.arc(originX, originY, radius, 0 * rad, 360 * rad, clockwise);
		context.fill();			
	}
	
	borderX = radius * (2 * prop - 1);
	
    context.setFillColor(0, 0, 0, 0.8);
	if (borderX == 0) {
		// 完全な半円
		if (sign < 0) {
			clockwise = true;
		} else {
			clockwise = false;
		}
		context.arc(originX, originY, radius, 90 * rad, 270 * rad, clockwise);
		context.fill();	
	} else {
		// (R-x)^2 + r^2 = R^2 
		R = (borderX * borderX + radius * radius) / (2 * Math.abs(borderX));
	    
	    y = originY;
		x = (borderX > 0)? (borderX - R) : (borderX + R);
		x = x * sign;

	    th = Math.acos(Math.abs(x) / R) / rad;
	
		x = originX + x;
	    
		context.beginPath();
		if (sign * borderX < 0) {
			context.arc(x, y, R, (180 - th) * rad, (180 + th) * rad, false);
		} else {
			context.arc(x, y, R, th * rad, (360 - th) * rad, true);
		}
		
		if (sign * borderX > 0) {
			clockwise = false;
		} else {
			clockwise = true;
		}
		if (prop >= 0.5) {
			// 半円以上
	//		context.arc(originX, originY, radius, 90 * rad, 270 * rad, clockwise);
			context.arc(originX, originY, radius, 270 * rad, 90 * rad, clockwise);
		} else {
			// 半円以下
			context.arc(originX, originY, radius, 90 * rad, 270 * rad, clockwise);		
		}
		context.closePath();
		context.fill();
	}
}

function showInfo()
{
	document.getElementById("info").style.display = "block";
}

function hideInfo()
{
	document.getElementById("info").style.display = "none";
}
